@@ -12,8 +12,9 @@ or result.bindings is a list of dicts of variables bindings
 
 import rdflib
 
-g=rdflib.Graph()
+g = rdflib.Graph()
 g.load("foaf.rdf")
 
-for row in g.query('select ?s where { [] <http://xmlns.com/foaf/0.1/knows> ?s .}'): 
+for row in g.query(
+        'select ?s where { [] <http://xmlns.com/foaf/0.1/knows> ?s .}'):
     print row
